@@ -3,11 +3,6 @@
 # Description: File-system abstractions
 # Documentation: algorithms.txt
 
-# Remark 1.7.8
-# Copyright (c) 2009 - 2021
-# Kalle Rutanen
-# Distributed under the MIT license (see license.txt).
-
 from __future__ import print_function
 
 import os.path
@@ -288,7 +283,7 @@ def openFileUtf8(fileName):
     A handle to the opened file.
     '''
     file = codecs.open(longPath(fileName),
-                       mode = 'rU', encoding = 'utf-8-sig', 
+                       mode = 'r', encoding = 'utf-8-sig', 
                        errors = 'replace')
 
     return file    
@@ -333,7 +328,8 @@ def readFile(fileName, maxSize = -1):
     try:
         with openFileUtf8(fileName) as file:
             text = file.readlines()
-    except:
+    except Exception as e:
+        print(e)
         print
         print('Warning:', fileName, end = ' ')
         print('could not be read for some reason.', end = ' ')
